from setuptools import setup, find_packages

setup(
    name='pundass',
    version='0.1.0',
    description='hi',
    author='Semban2690',
    author_email='aaro@gmail.com',
    packages=find_packages(),
    install_requires=[
        'requests',
    ],
    python_requires='>=2.1',
)

